# **Perceptron Python package**


## Refrence

* [Official python docs for PYPY] (https://packaging.python.org/en/latest/tutorials/packaging-projects/)

* [Github Action file for PYPY] (https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)

# To check packages list use
```
pip list
```
# How to use
```
from mn.perceptron import Perceptron
```